use chrono::{NaiveDate, NaiveDateTime};
use libretunes_macro::db_type;
use serde::{Deserialize, Serialize};

#[db_type(crate::schema::songs)]
#[derive(Clone, Serialize, Deserialize)]
pub struct Song {
    /// A unique id for the song
    #[omit_new]
    pub id: i32,
    /// The song's title
    pub title: String,
    /// The album the song is from
    pub album_id: Option<i32>,
    /// The track number of the song on the album
    pub track: Option<i32>,
    /// The duration of the song in seconds
    pub duration: i32,
    /// The song's release date
    pub release_date: Option<NaiveDate>,
    /// The path to the song's audio file
    pub storage_path: String,
    /// The path to the song's image file
    pub image_path: Option<String>,
    /// The date the song was added to the database
    #[omit_new]
    pub added_date: NaiveDateTime,
}
