use leptos::logging::log;

use lazy_static::lazy_static;
use std::env;
use tower_sessions_redis_store::fred;
use tower_sessions_redis_store::fred::prelude::*;

lazy_static! {
    static ref REDIS_POOL: fred::clients::Pool = init_redis_pool();
}

fn init_redis_pool() -> fred::clients::Pool {
    let redis_url = env::var("REDIS_URL").expect("REDIS_URL must be set");

    let redis_config = fred::types::config::Config::from_url(&redis_url)
        .unwrap_or_else(|_| panic!("Unable to parse Redis URL: {redis_url}"));

    let redis_pool = fred::clients::Pool::new(redis_config, None, None, None, 1)
        .expect("Unable to create Redis pool");

    log!("Connecting to Redis: {redis_url}");

    redis_pool.connect();
    redis_pool
}

pub fn get_redis_pool() -> fred::clients::Pool {
    REDIS_POOL.clone()
}

pub fn get_redis_conn() -> fred::clients::Client {
    REDIS_POOL.next().clone()
}
