use cfg_if::cfg_if;

cfg_if! {
    if #[cfg(feature = "reqwest_api")] {
        pub type Client = CustomClient;

        use reqwest;
        use std::future::Future;
        use server_fn::ServerFnError;
        use futures::TryFutureExt;
        use once_cell::sync::Lazy;

        /// Static global client
        static CLIENT: Lazy<reqwest::Client> = Lazy::new(|| reqwest::Client::builder()
            .cookie_store(true)
            .build()
            .unwrap());

        /// A custom client for `server_fn` that uses `reqwest`.
        /// Very similar to `server_fn::client::reqwest::ReqwestClient`,
        /// but with the cookies enabled to allow for authentication.
        pub struct CustomClient;

        impl <CustErr> server_fn::client::Client<CustErr> for CustomClient {
            type Request = reqwest::Request;
            type Response = reqwest::Response;

            fn send(
                req: Self::Request
            ) -> impl Future<Output = Result<Self::Response, ServerFnError<CustErr>>>
                 + Send {
                CLIENT
                    .execute(req)
                    .map_err(|e| ServerFnError::Request(e.to_string()))
            }
        }
    } else {
        pub type Client = server_fn::client::browser::BrowserClient;
    }
}
